@@ -1,10 +1,16 @@
 // Keep alphabetically sorted
 // TODO: sort alphabetically
 // TODO: remove all constants except those used within sagas
+export const ADD_DISK_REMOVAL_PENDING_TASK = 'ADD_DISK_REMOVAL_PENDING_TASK'
+export const ADD_NETWORKS_TO_VNIC_PROFILES = 'ADD_NETWORKS_TO_VNIC_PROFILES'
+export const ADD_VM_NIC = 'ADD_VM_NIC'
+export const SET_VNIC_PROFILES = 'SET_VNIC_PROFILES'
+export const SET_VM_NICS = 'SET_VM_NICS'
 export const CHANGE_VM_ICON = 'CHANGE_VM_ICON'
 export const CHANGE_VM_ICON_BY_ID = 'CHANGE_VM_ICON_BY_ID'
 export const CHECK_TOKEN_EXPIRED = 'CHECK_TOKEN_EXPIRED'
 export const CLEAR_USER_MSGS = 'CLEAR_USER_MSGS'
+export const DELETE_VM_NIC = 'DELETE_VM_NIC'
 export const DOWNLOAD_CONSOLE_VM = 'DOWNLOAD_CONSOLE_VM'
 export const FAILED_EXTERNAL_ACTION = 'FAILED_EXTERNAL_ACTION'
 export const GET_ALL_CLUSTERS = 'GET_ALL_CLUSTERS'
@@ -12,6 +18,7 @@ export const GET_ALL_FILES_FOR_ISO = 'GET_ALL_FILES_FOR_ISO'
 export const GET_ALL_HOSTS = 'GET_ALL_HOSTS'
 export const GET_ALL_OS = 'GET_ALL_OS'
 export const GET_ALL_TEMPLATES = 'GET_ALL_TEMPLATES'
+export const GET_ALL_VNIC_PROFILES = 'GET_ALL_VNIC_PROFILES'
 export const GET_BY_PAGE = 'GET_BY_PAGE'
 export const GET_CONSOLE_OPTIONS = 'GET_CONSOLE_OPTIONS'
 export const GET_ISO_STORAGES = 'GET_ISO_STORAGES'
@@ -24,6 +31,9 @@ export const GET_USB_FILTER = 'GET_USB_FILTER'
 export const GET_VM = 'GET_VM'
 export const GET_VMS_BY_COUNT = 'GET_VMS_BY_COUNT'
 export const GET_VMS_BY_PAGE = 'GET_VMS_BY_PAGE'
+export const GET_ALL_STORAGE_DOMAINS = 'GET_ALL_STORAGE_DOMAINS'
+export const SET_STORAGE_DOMAINS = 'SET_STORAGE_DOMAINS'
+export const SET_DATA_CENTERS = 'SET_DATA_CENTERS'
 export const LOGIN_FAILED = 'LOGIN_FAILED'
 export const LOGIN = 'LOGIN'
 export const LOGIN_SUCCESSFUL = 'LOGIN_SUCCESSFUL'
@@ -34,6 +44,7 @@ export const POOL_ACTION_IN_PROGRESS = 'POOL_ACTION_IN_PROGRESS'
 export const REFRESH_DATA = 'REFRESH_DATA'
 export const REMOVE_MISSING_POOLS = 'REMOVE_MISSING_POOLS'
 export const REMOVE_MISSING_VMS = 'REMOVE_MISSING_VMS'
+export const REMOVE_DISK_REMOVAL_PENDING_TASK = 'REMOVE_DISK_REMOVAL_PENDING_TASK'
 export const REMOVE_POOL = 'REMOVE_POOL'
 export const REMOVE_POOLS = 'REMOVE_POOLS'
 export const REMOVE_VM = 'REMOVE_VM'
